@@ -141,45 +141,3 @@ sql_select.spark_connection <- function(con, select, from, where = NULL,
 
   escape(unname(compact(out)), collapse = "\n", parens = FALSE, con = con)
 }
-
-#' @export
-sql_join.spark_connection <- function(con, x, y, type = "inner", by = NULL, ...) {
-  # TODO: This function needs to be removed once dplyr can workaround this issue by avoiding USING statements.
-
-  sparkVersion <- spark_version(con)
-
-  if (compareVersion(toString(sparkVersion), "2.0.0") < 0) {
-    sameNameColumns <- length(Filter(function(e) by$x[[e]] == by$y[[e]], seq_len(length(by$x))))
-    if (sameNameColumns > 0) {
-      stop(paste("This dplyr operation requires a feature not supported in Spark", sparkVersion,
-                ". Try Spark 2.0.0 instead or avoid using same-column names in joins."))
-    }
-  }
-
-  # Invoke dplyrs default join:
-  join <- switch(type,
-                 left = sql("LEFT"),
-                 inner = sql("INNER"),
-                 right = sql("RIGHT"),
-                 full = sql("FULL"),
-                 stop("Unknown join type:", type, call. = FALSE)
-  )
-
-  using <- all(by$x == by$y)
-
-  if (using) {
-    cond <- build_sql("USING ", lapply(by$x, ident), con = con)
-  } else {
-    on <- sql_vector(paste0(sql_escape_ident(con, by$x), " = ", sql_escape_ident(con, by$y)),
-                     collapse = " AND ", parens = TRUE)
-    cond <- build_sql("ON ", on, con = con)
-  }
-
-  build_sql(
-    'SELECT * FROM ',x, "\n\n",
-    join, " JOIN\n\n" ,
-    y, "\n\n",
-    cond,
-    con = con
-  )
-}
