@@ -12,4 +12,9 @@ set_option_default <- function(...) {
   set_option_default(
     sparklyr.na.action.verbose = TRUE
   )
+
+  overwrite_dplyr_top_n()
+  setHook(packageEvent("dplyr", "attach"), function(...) {
+    overwrite_dplyr_top_n()
+  })
 }
